@@ -137,8 +137,8 @@ class CidrIterator:
     # so we don't try to be compatible with python2 (this would require calling iter.next()
     # instead of iter.__next__().
 
-    def __init__(self, iter):
-        self._iter = iter
+    def __init__(self, child_iter):
+        self._iter = iter(child_iter)
         self._count = 0 # number of items read consumed
         self._saved = None
 
